@@ -9,7 +9,13 @@ with 'Pod::Weaver::Role::Section';
 
 use Moose::Autobox;
 
-our $VERSION = '0.02'; # VERSION
+has text => (
+    is => 'rw',
+    isa => 'Str',
+    default => q{Please visit the project's homepage at L<%s>.},
+);
+
+our $VERSION = '0.03'; # VERSION
 
 sub weave_section {
   my ($self, $document, $input) = @_;
@@ -18,7 +24,7 @@ sub weave_section {
   my $homepage = $input->{distmeta}{resources}{homepage} //
       "https://metacpan.org/release/$name";
 
-  my $text = "Please visit the project's homepage at L<$homepage>.";
+  my $text = sprintf $self->text, $homepage;
 
   #$text = Text::Wrap::wrap(q{}, q{}, $text);
 
@@ -41,12 +47,16 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Pod::Weaver::Section::Homepage::DefaultCPAN - Add a HOMEPAGE section (homepage defaults to MetaCPAN release page)
 
+=head1 VERSION
+
+This document describes version 0.03 of Pod::Weaver::Section::Homepage::DefaultCPAN (from Perl distribution Pod-Weaver-Section-Homepage-DefaultCPAN), released on 2015-01-07.
+
 =head1 SYNOPSIS
 
 In your C<weaver.ini>:
@@ -66,24 +76,29 @@ MetaCPAN release page if C<homepage> is not specified.
 
 =for Pod::Coverage weave_section
 
+=head1 ATTRIBUTES
+
+=head2 text
+
+The text that is added. C<%s> is replaced by the homepage url.
+
+Default: C<Please visit the project's homepage at LE<lt>%sE<gt>.>
+
 =head1 SEE ALSO
 
 L<Pod::Weaver::Section::Availability>
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at
-L<https://metacpan.org/release/Pod-Weaver-Section-Homepage-DefaultCPAN>.
+Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Section-Homepage-DefaultCPAN>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Pod-Weaver-Section-Homepage-DefaultCPAN>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Section-Homepage-DefaultCPAN>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Section-Homepag
-e-DefaultCPAN
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Section-Homepage-DefaultCPAN>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -91,11 +106,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
